@@ -3,6 +3,12 @@ import RPIO
 from hautomation_gpio import USED_GPIO_LIST
 
 
+def is_input(address):
+    return RPIO.gpio_function(int(address)) == RPIO.IN
+
+
+def is_output(address):
+    return RPIO.gpio_function(int(address)) == RPIO.OUT
 
 
 def validate_address(address):
